# PyDNB

This library contains method for learning and inference of an extension of hidden Markov model called dynamic naive
Bayes. The library use principles from dynamic Bayesian network but handle the network as a hidden Markov model.